==> xs2a-impl-2.11-sources.jar: de/adorsys/psd2/xs2a/web/validator/TransactionListMethodValidatorImpl.java <==
/*
 * Copyright 2018-2019 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.web.validator;

import de.adorsys.psd2.xs2a.web.validator.body.BodyValidator;
import de.adorsys.psd2.xs2a.web.validator.header.account.TransactionListHeaderValidator;
import de.adorsys.psd2.xs2a.web.validator.query.account.TransactionListQueryParamsValidator;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;

@Component
public class TransactionListMethodValidatorImpl extends AbstractMethodValidator<TransactionListHeaderValidator, RawBodyValidator, BodyValidator, TransactionListQueryParamsValidator> {
    private static final String METHOD_NAME = "_getTransactionList";

    protected TransactionListMethodValidatorImpl(List<TransactionListHeaderValidator> headerValidators,
                                                 List<TransactionListQueryParamsValidator> queryParamsValidator) {
        super(headerValidators, Collections.emptyList(), Collections.emptyList(), queryParamsValidator);
    }

    @Override
    public String getMethodName() {
        return METHOD_NAME;
    }
}

==> xs2a-impl-4.0.1-sources.jar: de/adorsys/psd2/xs2a/web/validator/TransactionListMethodValidatorImpl.java <==
/*
 * Copyright 2018-2019 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.web.validator;

import de.adorsys.psd2.xs2a.web.validator.body.BodyValidator;
import de.adorsys.psd2.xs2a.web.validator.header.account.TransactionListHeaderValidator;
import de.adorsys.psd2.xs2a.web.validator.path.PathParameterValidator;
import de.adorsys.psd2.xs2a.web.validator.query.account.TransactionListQueryParamsValidator;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;

@Component
public class TransactionListMethodValidatorImpl extends AbstractMethodValidator<TransactionListHeaderValidator, BodyValidator, TransactionListQueryParamsValidator, PathParameterValidator> {
    private static final String METHOD_NAME = "_getTransactionList";

    protected TransactionListMethodValidatorImpl(List<TransactionListHeaderValidator> headerValidators,
                                                 List<TransactionListQueryParamsValidator> queryParamsValidator) {
        super(headerValidators, Collections.emptyList(), queryParamsValidator, Collections.emptyList());
    }

    @Override
    public String getMethodName() {
        return METHOD_NAME;
    }
}
